import * as React from 'react';
import Link from '@mui/material/Link';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Title from './Title';
import axios from 'axios';
import { useEffect } from 'react';

interface Row {
    symbol: string;
    spread: string;
}

function preventDefault(event: React.MouseEvent) {
    event.preventDefault();
}

export default function FundingRateSpread() {
    const [rows, setRows] = React.useState<Row[]>([]);

    useEffect(() => {
        const fetchData = async () => {
            try {
                const response = await axios.get('http://localhost:4000/futures/futuresSpotSpread');
                setRows(response.data);
            } catch (error) {
                console.error('Error fetching data:', error);
            }
        };
        fetchData();

        const intervalId = setInterval(fetchData, 5000);

        return () => clearInterval(intervalId);
    }, []);

    return (
        <>
            <Title>Futures - Spot Spread</Title>
            <Table size="small">
                <TableHead>
                    <TableRow>
                        <TableCell>Symbol</TableCell>
                        <TableCell>Spread</TableCell>
                    </TableRow>
                </TableHead>
                <TableBody>
                {rows.map((row, i) => (
                        <TableRow key={i}>
                            <TableCell>{row.symbol}</TableCell>
                            <TableCell>{((parseFloat(row.spread) - 1) * 100).toLocaleString()}%</TableCell>
                        </TableRow>
                    ))}
                </TableBody>
            </Table>
        </>
    );
}