import * as React from 'react';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Title from './Title';
import axios from 'axios';
import { useEffect, useState } from 'react';

interface AccountInformation {
    feeTier: number;
    canTrade: boolean;
    canDeposit: boolean;
    canWithdraw: boolean;
    tradeGroupId: number;
    updateTime: number;
    multiAssetsMargin: boolean;
    totalInitialMargin: string;
    totalMaintMargin: string;
    totalWalletBalance: string;
    totalUnrealizedProfit: string;
    totalMarginBalance: string;
    totalPositionInitialMargin: string;
    totalOpenOrderInitialMargin: string;
    totalCrossWalletBalance: string;
    totalCrossUnPnl: string;
    availableBalance: string;
    maxWithdrawAmount: string;
}

export default function Profile() {
    const [accountInfo, setAccountInfo] = useState<AccountInformation | null>(null);

    useEffect(() => {
        const fetchData = async () => {
            try {
                const response = await axios.get('http://localhost:4000/futures/accountInformation');
                setAccountInfo(response.data);
            } catch (error) {
                console.error('Error fetching data:', error);
            }
        };

        fetchData();

        const intervalId = setInterval(fetchData, 5000);

        return () => clearInterval(intervalId);
    }, []);

    return (
        <>
            <Title>Profile</Title>
            {accountInfo && (
                <Table size="small">
                    <TableBody>
                        <TableRow>
                            <TableCell>% Margin</TableCell>
                            <TableCell>{(Number(accountInfo.totalInitialMargin) * 100 /Number(accountInfo.availableBalance)).toLocaleString()}%</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Initial Margin</TableCell>
                            <TableCell>{accountInfo.totalInitialMargin}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Maintenance Margin</TableCell>
                            <TableCell>{accountInfo.totalMaintMargin}</TableCell>
                        </TableRow>
                        {/*<TableRow>
                            <TableCell>Fee Tier</TableCell>
                            <TableCell>{accountInfo.feeTier}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Trade</TableCell>
                            <TableCell>{accountInfo.canTrade ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Deposit</TableCell>
                            <TableCell>{accountInfo.canDeposit ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Withdraw</TableCell>
                            <TableCell>{accountInfo.canWithdraw ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Total Wallet Balance</TableCell>
                            <TableCell>{accountInfo.totalWalletBalance}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Total Unrealized Profit</TableCell>
                            <TableCell>{accountInfo.totalUnrealizedProfit}</TableCell>
                        </TableRow>*/}
                        <TableRow>
                            <TableCell>Total Margin Balance</TableCell>
                            <TableCell>{accountInfo.totalMarginBalance}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Available Balance</TableCell>
                            <TableCell>{accountInfo.availableBalance}</TableCell>
                        </TableRow>
                        {/*<TableRow>
                            <TableCell>Max Withdraw Amount</TableCell>
                            <TableCell>{accountInfo.maxWithdrawAmount}</TableCell>
                        </TableRow>*/}
                    </TableBody>
                </Table>
            )}
        </>
    );
}
