import * as React from 'react';
import Table from '@mui/material/Table';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import TableHead from '@mui/material/TableHead';
import TableRow from '@mui/material/TableRow';
import Title from './Title';
import axios from 'axios';
import { useEffect, useState } from 'react';
import { useAuth } from '../../contexts/AuthContext';
import { axiosPrivate } from '../../api/axios';
import { Typography } from '@mui/material';
import Link from 'next/link';

interface AccountInformation {
    feeTier: number;
    canTrade: boolean;
    canDeposit: boolean;
    canWithdraw: boolean;
    tradeGroupId: number;
    updateTime: number;
    multiAssetsMargin: boolean;
    totalInitialMargin: string;
    totalMaintMargin: string;
    totalWalletBalance: string;
    totalUnrealizedProfit: string;
    totalMarginBalance: string;
    totalPositionInitialMargin: string;
    totalOpenOrderInitialMargin: string;
    totalCrossWalletBalance: string;
    totalCrossUnPnl: string;
    availableBalance: string;
    maxWithdrawAmount: string;
}

interface PageProps {
    id: string | string[] | undefined
    title?: string
    clickable?: boolean
}

export default function Profile({id, title, clickable = false}:PageProps) {
    const { token } = useAuth();
    const [accountInfo, setAccountInfo] = useState<AccountInformation | null>(null);
    const [error, setError] = useState(false);

    useEffect(() => {
        const fetchData = async () => {
            if(!token){
                return;
            }
            try {
                const response = await axiosPrivate(token).get('/futures/accountInformation?id='+id);
                setAccountInfo(response.data);
                setError(false);
            } catch (error) {
                console.error('Error fetching data:', error);
                setError(true);
            }
        };

        fetchData();

        const intervalId = setInterval(fetchData, 5000);

        return () => clearInterval(intervalId);
    }, []);

    return (
        <>
            {clickable?
            <Link href={'/portfolio/'+id} style={{textDecoration: 'none'}}>
                <Title>{title??'Profile'}</Title>
            </Link>
            :
            <Title>{title??'Profile'}</Title>
            }
            {error &&(
                <Typography color='error'>
                    Invalid API Key
                </Typography>
            )}
            {accountInfo && (
                <Table size="small">
                    <TableBody>
                        <TableRow>
                            <TableCell>% Margin</TableCell>
                            <TableCell>{(Number(accountInfo.totalInitialMargin) * 100 /Number(accountInfo.availableBalance)).toLocaleString()}%</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Initial Margin</TableCell>
                            <TableCell>{accountInfo.totalInitialMargin}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Maintenance Margin</TableCell>
                            <TableCell>{accountInfo.totalMaintMargin}</TableCell>
                        </TableRow>
                        {/*<TableRow>
                            <TableCell>Fee Tier</TableCell>
                            <TableCell>{accountInfo.feeTier}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Trade</TableCell>
                            <TableCell>{accountInfo.canTrade ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Deposit</TableCell>
                            <TableCell>{accountInfo.canDeposit ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Can Withdraw</TableCell>
                            <TableCell>{accountInfo.canWithdraw ? 'Yes' : 'No'}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Total Wallet Balance</TableCell>
                            <TableCell>{accountInfo.totalWalletBalance}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Total Unrealized Profit</TableCell>
                            <TableCell>{accountInfo.totalUnrealizedProfit}</TableCell>
                        </TableRow>*/}
                        <TableRow>
                            <TableCell>Total Margin Balance</TableCell>
                            <TableCell>{accountInfo.totalMarginBalance}</TableCell>
                        </TableRow>
                        <TableRow>
                            <TableCell>Available Balance</TableCell>
                            <TableCell>{accountInfo.availableBalance}</TableCell>
                        </TableRow>
                        {/*<TableRow>
                            <TableCell>Max Withdraw Amount</TableCell>
                            <TableCell>{accountInfo.maxWithdrawAmount}</TableCell>
                        </TableRow>*/}
                    </TableBody>
                </Table>
            )}
        </>
    );
}
