import { TextField } from "@mui/material";
import React from "react";
import { FieldError } from "../../pages";
import { ApiKeyForm } from "../../pages/dashboard";

interface UpdateApiKeyProps {
  getFieldError: (field: string) => FieldError;
  formState: ApiKeyForm,
  setFormState: React.Dispatch<React.SetStateAction<ApiKeyForm>>
 }
 
const UpdateApiKey = ({getFieldError, formState, setFormState}:UpdateApiKeyProps) => {
  return (
    <>
      <TextField
        error={getFieldError("title").valid}
        margin="normal"
        required
        fullWidth
        id="title"
        label="Title"
        name="title"
        autoComplete="title"
        autoFocus
        helperText={getFieldError("title").text}
        value={formState.title}
        onChange={(e) => {setFormState({...formState,[e.target.name]: e.target.value})}}
      />
      <TextField
        error={getFieldError("key").valid}
        margin="normal"
        required
        fullWidth
        name="key"
        label="Key"
        id="key"
        autoComplete="key"
        helperText={getFieldError("key").text}
        multiline
        rows={4}
        value={formState.key}
        onChange={(e) => {setFormState({...formState,[e.target.name]: e.target.value})}}
      />
      <TextField
        error={getFieldError("secret").valid}
        margin="normal"
        required
        fullWidth
        id="secret"
        label="Secret"
        name="secret"
        autoComplete="secret"
        autoFocus
        helperText={getFieldError("secret").text}
        multiline
        rows={4}
        value={formState.secret}
        onChange={(e) => {setFormState({...formState,[e.target.name]: e.target.value})}}
      />
    </>
  );
};

export default UpdateApiKey;
