import * as React from 'react';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemIcon from '@mui/material/ListItemIcon';
import ListItemText from '@mui/material/ListItemText';
import ListSubheader from '@mui/material/ListSubheader';
import DashboardIcon from '@mui/icons-material/Dashboard';
import ShoppingCartIcon from '@mui/icons-material/ShoppingCart';
import PeopleIcon from '@mui/icons-material/People';
import BarChartIcon from '@mui/icons-material/BarChart';
import LayersIcon from '@mui/icons-material/Layers';
import AssignmentIcon from '@mui/icons-material/Key';
import LockIcon from '@mui/icons-material/Lock';
import ProfileIcon from '@mui/icons-material/Home';
import ManageIcon from '@mui/icons-material/Article';
import Link from 'next/link';
import { axiosPrivate } from '../../api/axios';
import { useAuth } from '../../contexts/AuthContext';
import { useRouter } from 'next/navigation';
import { Button, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle } from '@mui/material';


export const mainListItems = (
    <React.Fragment>
        <ListItemButton>
            <ListItemIcon>
                <DashboardIcon />
            </ListItemIcon>
            <ListItemText primary="Portfolio" />
        </ListItemButton>
    </React.Fragment>
);

export const SecondaryListItems = (): JSX.Element => {

    const { logout } = useAuth();
    const router = useRouter();

    const [openDialog, setOpenDialog] = React.useState(false);

    const doLogout = async () => {
        logout();
        router.push('/')
     }

    return(
        <React.Fragment>
        <ListSubheader component="div" inset>
            Sub Menu
        </ListSubheader>

        <Link href={'/dashboard'} style={{textDecoration: 'none', color: 'black'}}>
            <ListItemButton>
                <ListItemIcon>
                    <ProfileIcon />
                </ListItemIcon>
                <ListItemText primary="Home" />
            </ListItemButton>
        </Link>

        <Link href={'/dashboard/key-profile'} style={{textDecoration: 'none', color: 'black'}}>
            <ListItemButton>
                <ListItemIcon>
                    <AssignmentIcon />
                </ListItemIcon>
                <ListItemText primary="Keys Profile" />
            </ListItemButton>
        </Link>

        <Link href={'/dashboard/key-mgmt'} style={{textDecoration: 'none', color: 'black'}}>
            <ListItemButton>
                <ListItemIcon>
                    <ManageIcon />
                </ListItemIcon>
                <ListItemText primary="Key Management" />
            </ListItemButton>
        </Link>

        <Link href="#" onClick={() => setOpenDialog(true)} style={{textDecoration: 'none', color: 'black'}}>
            <ListItemButton>
                <ListItemIcon>
                    <LockIcon />
                </ListItemIcon>
                <ListItemText primary="Logout" />
            </ListItemButton>
        </Link>

        <Dialog
        open={openDialog}
        onClose={() => setOpenDialog(false)}
        aria-labelledby="alert-dialog-title"
        aria-describedby="alert-dialog-description"
      >
        <DialogTitle id="alert-dialog-title">
          {"Are you sure to logout?"}
        </DialogTitle>
        {/* <DialogContent>
          <DialogContentText id="alert-dialog-description">
            Let Google help apps determine location. This means sending anonymous
            location data to Google, even when no apps are running.
          </DialogContentText>
        </DialogContent> */}
        <DialogActions>
          <Button onClick={() => setOpenDialog(false)}>Cancel</Button>
          <Button onClick={doLogout} autoFocus>
            OK
          </Button>
        </DialogActions>
      </Dialog>

        
    </React.Fragment>
    )
}