import { Grid, Box, Card, CardContent, Typography, Button } from '@mui/material'
import { userInfo } from 'os'
import React, { useEffect, useState } from 'react'
import DashboardLayout from '../../components/dashboard/Layout'
import RequireLogin from '../../guards/RequireLogin'
import Link from 'next/link'
import { useAuth } from '../../contexts/AuthContext'
import { axiosPrivate } from '../../api/axios'
import { APIKeyType } from '.'
import Profile from '../../components/dashboard/Profile'



 interface TileProps {
  item: APIKeyType;
 }
 
 const Tile: React.FC<TileProps> = ({ item }) => {
  const [showDetails, setShowDetails] = useState(false);
 
  const toggleDetails = () => {
    setShowDetails(!showDetails);
  };

   // Function to truncate and replace the rest of the string with ***
 const truncateAndReplace = (str: string, startLength: number, replacement: string) => {
  return str.length > startLength ? str.substring(0, startLength) + replacement : str;
};

 
  return (
      <Card sx={{ minWidth: 275, margin: 2 }}>
        <CardContent>
            <Profile id={item.id.toString()} title={item.title} clickable />
        </CardContent>
      </Card>

  );
 };

const KeyProfile = () => {
  const {token, setNavTitle} = useAuth();
  const [apiKeys, setApiKeys] = useState<Array<APIKeyType>>([]);
  const [loading, setLoading] = useState<boolean>(true);

  const fetchData = async () => {
    try {
      if (token) {
        const response = await axiosPrivate(token).get("/api/apiKeys");
        const data: Array<APIKeyType> = response.data;
        setApiKeys(data);
        setLoading(false);
      }
    } catch (e) {
      setLoading(false);
      // TODO: Handle errors
    }
  };

  useEffect(() => {
    setNavTitle('Profile');
    fetchData();
  }, [token]);

  return (
    <RequireLogin>
    <DashboardLayout>
      <Grid container spacing={3}>
        {/* Main Content */}
        <Grid item xs={12}>
          {/* <Paper sx={{ p: 2, display: "flex", flexDirection: "column" }}> */}
            <Box sx={{ display: 'flex', justifyContent: 'center', alignItems: 'center', backgroundColor: '#f5f5f5',
          // minHeight: '100vh',
            }}>
             <Grid container spacing={2}>
                {loading ? (
                    <Grid item xs={12} style={{ textAlign: 'center' }}>
                        <p>Loading...</p>
                    </Grid>
                ) : (
                    apiKeys.map((item) => (
                        <Grid item xs={12} sm={6} md={4} key={item.id}>
                            <Tile item={item} />
                        </Grid>
                    ))
                )}
            </Grid>
            </Box>
          {/* </Paper> */}
        </Grid>
      </Grid>
    </DashboardLayout>
  </RequireLogin>
  )
}

export default KeyProfile

