import { useRouter } from "next/router";
import RequireLogin from "../../guards/RequireLogin";
import DashboardLayout from "../../components/dashboard/Layout";
import { Grid, Paper } from "@mui/material";
import FundingRate from "../../components/dashboard/FundingRate";
import FundingRateSpread from "../../components/dashboard/FundingRateSpread";
import Profile from "../../components/dashboard/Profile";
import { useEffect } from "react";
import FuturesPositions from "../../components/dashboard/FuturesPositions";
import { axiosPrivate } from "../../api/axios";
import { useAuth } from "../../contexts/AuthContext";

export default function WalletID() {
  const { setNavTitle, token } = useAuth();
  const router = useRouter();
  const walletID = router.query["wallet-id"];
  console.log(walletID);

  if(!walletID){
    return <></>
  }

  const fetchData = async () => {
    try {
      if (token) {
        const response = await axiosPrivate(token).get("/api/apiKeys/"+walletID);
        const data = response.data;
        setNavTitle('Portfolio - '+data['title']);
      }
    } catch (e) {
      // TODO: Handle errors
    }
  };

  useEffect(() => {
    fetchData();
  }, [token]);

  return (
    <RequireLogin>
      <DashboardLayout>
        <Grid container spacing={3}>
          {/* Futures Position */}
          <Grid item xs={12}>
            <Paper sx={{ p: 2, display: "flex", flexDirection: "column" }}>
              <FuturesPositions id={walletID} />
            </Paper>
          </Grid>
          {/* Funding Rate */}
          <Grid item xs={12} md={4} lg={4}>
            <Paper
              sx={{
                p: 2,
                display: "flex",
                flexDirection: "column",
              }}
            >
              <FundingRate />
            </Paper>
          </Grid>
          {/* Funding Rate Spread */}
          <Grid item xs={12} md={4} lg={4}>
            <Paper
              sx={{
                p: 2,
                display: "flex",
                flexDirection: "column",
              }}
            >
              <FundingRateSpread />
            </Paper>
          </Grid>
          {/* Profile */}
          <Grid item xs={12} md={4} lg={4}>
            <Paper
              sx={{
                p: 2,
                display: "flex",
                flexDirection: "column",
              }}
            >
              <Profile id={walletID} />
            </Paper>
          </Grid>
        </Grid>
      </DashboardLayout>
    </RequireLogin>
  );
}
