import { createAsyncThunk, createSlice } from '@reduxjs/toolkit';
import axios, { axiosPrivate } from '../api/axios';

interface SpotPrice {
    symbol: string;
    bidPrice: string;
    bidQty: string;
    askPrice: string;
    askQty: string;
}

interface SpotPriceState {
    data: SpotPrice[];
    isLoading: boolean;
    errorMessage: string;
}

const initialState: SpotPriceState = {
    data: [],
    isLoading: false,
    errorMessage: '',
};

export const fetchSpotPrices = createAsyncThunk('spotPrice/fetchSpotPrices', async () => {
    try {
        const response = await axios.get<SpotPrice[]>('/spot/prices');
        return response.data;
    } catch (error) {
        throw new Error('Failed to fetch spot prices');
    }
});

const spotPriceSlice = createSlice({
    name: 'spotPrice',
    initialState,
    reducers: {},
    extraReducers: (builder) => {
        builder
            .addCase(fetchSpotPrices.pending, (state) => {
                state.isLoading = true;
                state.errorMessage = '';
            })
            .addCase(fetchSpotPrices.fulfilled, (state, action) => {
                state.isLoading = false;
                state.data = action.payload;
            })
            .addCase(fetchSpotPrices.rejected, (state, action) => {
                state.isLoading = false;
                state.errorMessage = action.error.message ?? 'Failed to fetch spot prices';
            });
    },
});

export default spotPriceSlice.reducer;
